/*
 * Licensed Materials - Property of IBM
 * com.ibm.ws.ast.samples
 *  Copyright IBM Corporation 2010. All Rights Reserved.
 * U.S. Government Users Restricted Rights - Use, duplication or disclosure restricted by GSA ADP Schedule Contract with IBM Corp.
 * Use restricted, please refer to the "Samples Gallery" terms and conditions in the IBM International Program License Agreement.   
 */
package bigbank.account;

import java.util.ArrayList;
import java.util.List;

import org.osoa.sca.annotations.Property;
import org.osoa.sca.annotations.Reference;

import bigbank.accountdata.AccountDataService;
import bigbank.accountdata.CheckingAccount;
import bigbank.accountdata.SavingsAccount;
import bigbank.accountdata.StockAccount;
import bigbank.stockquote.StockQuoteService;

/**
 * Account service implementation
 */
public class AccountServiceImpl implements AccountService {

    @Reference
    public AccountDataService accountDataService;
    
    @Reference
    public StockQuoteService stockQuoteService;
    
    @Property
    public String currency;

    public AccountReport getAccountReport(String s) {
        List<String> summaries = new ArrayList<String>();

        CheckingAccount ca = accountDataService.getCheckingAccount(s);
        summaries.add(ca.getSummary());

        SavingsAccount sa = accountDataService.getSavingsAccount(s);
        summaries.add(sa.getSummary());

        StockAccount sk = accountDataService.getStockAccount(s);
        
        double price = stockQuoteService.getQuote(sk.getSymbol());
        sk.setBalance(sk.getQuantity() * price);
        
        summaries.add(sk.getSummary());

        AccountReport report = new AccountReport(currency, summaries);
        
        return report;
    }

}
